==> facebook_album-7.x-1.0.tar.gz: facebook_album/js/facebook_album.js <==
/**
 * @file facebook_album.js
 * The plugin that retrieves the information from facebook.
 *
 * Version: 1.x
 * Drupal Core: 7.x
 *
 */

(function($) {
  /*
  * Define the custom object
  * This isn't actually needed at this point, 
  * but using for future extendability
  */
  Drupal.facebookAlbum = Drupal.facebookAlbum || {};

  // Initialize the albums
  Drupal.facebookAlbum.initialize = function(options){
    var cbProps = ("rel:'fbGal', maxWidth:'95%', maxHeight:'95%', " + Drupal.settings.facebookAlbum.colorboxOptions).split(',');
    var cbOptions = {};
    
    for(i = 0; i < cbProps.length; i++){
      var prop = cbProps[i].split(':');
      cbOptions[prop[0]] = prop[1];
    }
    var widthRatio = 1;
    
    // Resize based on screen
    if($(window).width() < Drupal.settings.facebookAlbum.albumThumbWidth){
      widthRatio = Drupal.settings.facebookAlbum.albumThumbWidth / ($(window).width() - 100);
      Drupal.settings.facebookAlbum.albumThumbWidth = $(window).width() - 100;
      Drupal.settings.facebookAlbum.albumThumbHeight = Drupal.settings.facebookAlbum.albumThumbHeight / widthRatio;
    }
    
    if($(window).width() < Drupal.settings.facebookAlbum.photoThumbWidth){
      widthRatio = Drupal.settings.facebookAlbum.photoThumbWidth / ($(window).width() - 100);
      Drupal.settings.facebookAlbum.photoThumbWidth = $(window).width() - 100;
      Drupal.settings.facebookAlbum.photoThumbHeight = Drupal.settings.facebookAlbum.photoThumbHeight / widthRatio;
    }
    
    options = $.extend({
      pageId : Drupal.settings.facebookAlbum.pageID,
      id : "facebook-album",
      visibility: Drupal.settings.facebookAlbum.visibility,
      albums : Drupal.settings.facebookAlbum.albums,      
      albumRows: 3,
      albumLimit: Drupal.settings.facebookAlbum.albumLimit,
      showDescription: Drupal.settings.facebookAlbum.showDescription,
      showLocation: Drupal.settings.facebookAlbum.showLocation,
      albumThumbWidth: Drupal.settings.facebookAlbum.albumThumbWidth,
      albumThumbHeight: Drupal.settings.facebookAlbum.albumThumbHeight,
      photoThumbWidth: Drupal.settings.facebookAlbum.photoThumbWidth,
      photoThumbHeight: Drupal.settings.facebookAlbum.photoThumbHeight,
      colorboxOptions : cbOptions
    }, options);

    var offset = 0;
    var photoOffset = 0;
    var albumId = "";
    var headerArray = new Array();

    function initializeAlbums() {
      $('#fb-album-header').html("");
      if($('#fb-albums-wrapper').length != 0) {
        $('#fb-albums-wrapper').fadeIn(1000);
      } else {
        $("<div>", {
          id : "fb-albums-wrapper"
        }).appendTo("#fb-album-content");

        loadAlbums();
      }
    }

    function loadAlbums() {
      // TODO: currently calling all albums, should probably limit this
      FB.api(options.pageId + '/albums', {}, function(response) {
        var albumCount = 1;
        for(var i in response.data) {
          
          // Stop on limit
          if(albumCount > options.albumLimit) {
            break;
          }
          
          var album = response.data[i];
          // Includes/Excludes
          if(options.albums != ""){
            if(options.visibility && $.inArray(album.id, options.albums) == -1){
              continue;
            }
            else if(!options.visibility && $.inArray(album.id, options.albums) != -1){
              continue;
            } 
          }
            
          var countTxt = album.count + " ";
          if(album.count > 1) {
            countTxt += "Images";
          } else {
            countTxt += "Image";
          }
          
          // Break rows
          var clear = "";
          var rowCheck = $('.album-thumb').length % options.albumRows;
          if(rowCheck == 0){
            clear = ";clear:both";
          }
          
          var html = '<div class="album-thumb fb-link" title="' + album.name + '" href="#album-' + album.id + '">';
          html += '<span class="album-thumb-wrapper">';
          html += '<i id="fb-album-thumb-' + album.cover_photo + '" style="width:' + options.albumThumbWidth + 'px;height:' + options.albumThumbHeight + 'px;"></i>';
          html += '</span>';
          html += '</div>';
          html += '<div class="album-details">';
          html += '<div class="album-text">';
          html += '<div class="fb-link" href="#album-' + album.id + '">' + album.name + '</div>';
          html += '</div>';
          $("<div>", {
            "class" : "album-wrapper",
            style: clear,
            html : html
          }).appendTo("#fb-albums-wrapper").fadeIn(1000,function(){
            $('#facebook-album').on('click', '.fb-link', function(e){
              clickHandler($(this).attr('href'));
            });
          });

          FB.api(album.cover_photo, function(response) {
            var img = response.source;
            $("#fb-album-thumb-" + response.id).css("background-image", "url(" + img + ")");
          });
          albumCount++;
        }
      });
    }

    function displayAlbum() {
      if($('#fb-album-' + albumId).length != 0) {
        $('#fb-album-' + albumId).fadeIn(500);
        $('#fb-album-header').html(headerArray[albumId]);
          
        $('.fb-link').bind('click',function(e){
          clickHandler($(this).attr('href'));
        });
      } else {
        FB.api(albumId, function(response) {
          var albname = response.name;
          var desc = "";
          if(response.description && options.showDescription){
            desc += response.description;
          }
          if(response.location && options.showLocation){
            if(desc != ""){
              desc += ' ';
            } 
            desc += '(' + Drupal.t('Taken in') + ' ' + response.location + ')';
          }
          if(desc != ''){
            desc ='<p>' + desc + '</p>';
          }
          header = '<span href="#" class="fb-link" >&laquo; ' + Drupal.t('Back to Albums') + '</span> - <b>' + albname + '</b>' + desc;

          headerArray[albumId] = header;
          $('#fb-album-header').html(header);
          $("<div>", {
            id : 'fb-album-' + albumId,
            "class" : 'album'
          }).appendTo("#fb-album-content");
          photoOffset = 0;
          loadPhoto();
          
          $('#facebook-album').on('click', '.fb-link', function(e){
            clickHandler($(this).attr('href'));
          });
        });
      }
    }

    function loadPhoto() {
      FB.api(albumId + '/photos', { limit : 25, offset : photoOffset * 25}, function(response) {
        for(var i in response.data) {
          var photo = response.data[i];

          // Don't include tiny images
          var img = "";
          for(var j in photo.images) {
            image = photo.images[j];
            if(image.height > 100 && image.width > 150) {
              img = image.source;
            } else {
              break;
            }
          }
          var name = "";
          if(photo.name) {
            name = photo.name;
          }

          var html = '<a class="photo-thumb ' + albumId + '" title="' + name + '" href="' + photo.source + '">';
          html += '<span class="photo-thumb-wrapper">';
          html += '<i style="width:' + options.photoThumbWidth + 'px;height:' + options.photoThumbHeight + 'px;background-image:url(' + photo.source + ')"></i>';
          html += '</span>';
          html += '</a>';
          $("<div>", {
            id : 'fb-photo-' + photo.id,
            "class" : "photo-wrapper",
            html : html
          }).appendTo('#fb-album-' + albumId).fadeIn(500);
        }
        if(response.data.length > 0) {
          photoOffset++;
          loadPhoto();
        } else if ($.fn.colorbox) {
          $('a.' + albumId).colorbox(options.colorboxOptions);
        }
      });
    }

    /**
     * TODO: Clean this up
     */
    function clickHandler(href) {
      var base = href.split('-');
      if(base[0] == '#album') {
        if($('#fb-albums-wrapper').length != 0) {
          $('#fb-albums-wrapper').hide();
        }
        albumId = base[1];
        displayAlbum();
      } else {
        $('.album').hide();
        initializeAlbums();
      }
    }
    
    // Setup display
    $("<div>", {
      id : "fb-album-header"
    }).appendTo("#" + options.id);

    $("<div>", {
      id : "fb-album-content"
    }).appendTo("#" + options.id);

    $("<div>", {
      "class" : "fb-album-footer",
      style : 'clear:both',
    }).appendTo("#" + options.id);
    
    $('.album').hide();
    
    initializeAlbums();
  };
  
  $(document).ready(function(){
    if(Drupal.settings.facebookAlbum.pageID.length){
      Drupal.facebookAlbum.initialize();
    }
  });
  
})(jQuery);

==> facebook_album-7.x-1.1.tar.gz: facebook_album/js/facebook_album.js <==
/**
 * @file facebook_album.js
 * The plugin that retrieves the information from facebook.
 *
 * Version: 1.x
 * Drupal Core: 7.x
 *
 */

(function($) {
  /*
  * Define the custom object
  * This isn't actually needed at this point, 
  * but using for future extendability
  */
  Drupal.facebookAlbum = Drupal.facebookAlbum || {};

  // Initialize the albums
  Drupal.facebookAlbum.initialize = function(options){
    var cbProps = ("rel:'fbGal', maxWidth:'95%', maxHeight:'95%', " + Drupal.settings.facebookAlbum.colorboxOptions).split(',');
    var cbOptions = {};
    
    for(i = 0; i < cbProps.length; i++){
      var prop = cbProps[i].split(':');
      cbOptions[prop[0].replace(/ /g,'')] = prop[1].replace(/\"|\'/g, "");
    }
    var widthRatio = 1;
    
    // Resize based on screen
    if($(window).width() < Drupal.settings.facebookAlbum.albumThumbWidth){
      widthRatio = Drupal.settings.facebookAlbum.albumThumbWidth / ($(window).width() - 100);
      Drupal.settings.facebookAlbum.albumThumbWidth = $(window).width() - 100;
      Drupal.settings.facebookAlbum.albumThumbHeight = Drupal.settings.facebookAlbum.albumThumbHeight / widthRatio;
    }
    
    if($(window).width() < Drupal.settings.facebookAlbum.photoThumbWidth){
      widthRatio = Drupal.settings.facebookAlbum.photoThumbWidth / ($(window).width() - 100);
      Drupal.settings.facebookAlbum.photoThumbWidth = $(window).width() - 100;
      Drupal.settings.facebookAlbum.photoThumbHeight = Drupal.settings.facebookAlbum.photoThumbHeight / widthRatio;
    }
    
    options = $.extend({
      pageId : Drupal.settings.facebookAlbum.pageID,
      id : "facebook-album",
      visibility: Drupal.settings.facebookAlbum.visibility,
      albums : Drupal.settings.facebookAlbum.albums,      
      albumRows: 3,
      albumLimit: Drupal.settings.facebookAlbum.albumLimit,
      showDescription: Drupal.settings.facebookAlbum.showDescription,
      showLocation: Drupal.settings.facebookAlbum.showLocation,
      albumThumbWidth: Drupal.settings.facebookAlbum.albumThumbWidth,
      albumThumbHeight: Drupal.settings.facebookAlbum.albumThumbHeight,
      photoThumbWidth: Drupal.settings.facebookAlbum.photoThumbWidth,
      photoThumbHeight: Drupal.settings.facebookAlbum.photoThumbHeight,
      colorboxOptions : cbOptions
    }, options);

    var offset = 0;
    var photoOffset = 0;
    var albumId = "";
    var headerArray = new Array();

    function initializeAlbums() {
      $('#fb-album-header').html("");
      if($('#fb-albums-wrapper').length != 0) {
        $('#fb-albums-wrapper').fadeIn(1000);
      } else {
        $("<div>", {
          id : "fb-albums-wrapper"
        }).appendTo("#fb-album-content");

        loadAlbums();
      }
    }

    function loadAlbums() {
      // TODO: currently calling all albums, should probably limit this
      FB.api(options.pageId + '/albums', {}, function(response) {
        var albumCount = 1;
        for(var i in response.data) {
          
          // Stop on limit
          if(albumCount > options.albumLimit) {
            break;
          }
          
          var album = response.data[i];
          // Includes/Excludes
          if(options.albums != ""){
            if(options.visibility == 1 && $.inArray(album.id, options.albums) == -1){
              continue;
            }
            else if(options.visibility == 0 && $.inArray(album.id, options.albums) != -1){
              continue;
            } 
          }
            
          var countTxt = album.count + " ";
          if(album.count > 1) {
            countTxt += "Images";
          } else {
            countTxt += "Image";
          }
          
          // Break rows
          var clear = "";
          var rowCheck = $('.album-thumb').length % options.albumRows;
          if(rowCheck == 0){
            clear = ";clear:both";
          }
          
          var html = '<div class="album-thumb fb-link" title="' + album.name + '" href="#album-' + album.id + '">';
          html += '<span class="album-thumb-wrapper">';
          html += '<i id="fb-album-thumb-' + album.cover_photo + '" style="width:' + options.albumThumbWidth + 'px;height:' + options.albumThumbHeight + 'px;"></i>';
          html += '</span>';
          html += '</div>';
          html += '<div class="album-details">';
          html += '<div class="album-text">';
          html += '<div class="fb-link" href="#album-' + album.id + '">' + album.name + '</div>';
          html += '</div>';
          $("<div>", {
            "class" : "album-wrapper",
            style: clear,
            html : html
          }).appendTo("#fb-albums-wrapper").fadeIn(1000,function(){
            $('#facebook-album').on('click', '.fb-link', function(e){
              clickHandler($(this).attr('href'));
            });
          });

          FB.api(album.cover_photo, function(response) {
            var img = response.source;
            $("#fb-album-thumb-" + response.id).css("background-image", "url(" + img + ")");
          });
          albumCount++;
        }
      });
    }

    function displayAlbum() {
      if($('#fb-album-' + albumId).length != 0) {
        $('#fb-album-' + albumId).fadeIn(500);
        $('#fb-album-header').html(headerArray[albumId]);
          
        $('.fb-link').bind('click',function(e){
          clickHandler($(this).attr('href'));
        });
      } else {
        FB.api(albumId, function(response) {
          var albname = response.name;
          var desc = "";
          if(response.description && options.showDescription){
            desc += response.description;
          }
          if(response.location && options.showLocation){
            if(desc != ""){
              desc += ' ';
            } 
            desc += '(' + Drupal.t('Taken in') + ' ' + response.location + ')';
          }
          if(desc != ''){
            desc ='<p>' + desc + '</p>';
          }
          header = '<span href="#" class="fb-link" >&laquo; ' + Drupal.t('Back to Albums') + '</span> - <b>' + albname + '</b>' + desc;

          headerArray[albumId] = header;
          $('#fb-album-header').html(header);
          $("<div>", {
            id : 'fb-album-' + albumId,
            "class" : 'album'
          }).appendTo("#fb-album-content");
          photoOffset = 0;
          loadPhoto();
          
          $('#facebook-album').on('click', '.fb-link', function(e){
            clickHandler($(this).attr('href'));
          });
        });
      }
    }

    function loadPhoto() {
      FB.api(albumId + '/photos', { limit : 25, offset : photoOffset * 25}, function(response) {
        for(var i in response.data) {
          var photo = response.data[i];

          // Don't include tiny images
          var img = "";
          for(var j in photo.images) {
            image = photo.images[j];
            if(image.height > 100 && image.width > 150) {
              img = image.source;
            } else {
              break;
            }
          }
          var name = "";
          if(photo.name) {
            name = photo.name;
          }

          var html = '<a class="photo-thumb ' + albumId + '" title="' + name + '" href="' + photo.source + '">';
          html += '<span class="photo-thumb-wrapper">';
          html += '<i style="width:' + options.photoThumbWidth + 'px;height:' + options.photoThumbHeight + 'px;background-image:url(' + photo.source + ')"></i>';
          html += '</span>';
          html += '</a>';
          $("<div>", {
            id : 'fb-photo-' + photo.id,
            "class" : "photo-wrapper",
            html : html
          }).appendTo('#fb-album-' + albumId).fadeIn(500);
        }
        if(response.data.length > 0) {
          photoOffset++;
          loadPhoto();
        } else if ($.fn.colorbox) {
          $('a.' + albumId).colorbox(options.colorboxOptions);
        }
      });
    }

    /**
     * TODO: Clean this up
     */
    function clickHandler(href) {
      var base = href.split('-');
      if(base[0] == '#album') {
        if($('#fb-albums-wrapper').length != 0) {
          $('#fb-albums-wrapper').hide();
        }
        albumId = base[1];
        displayAlbum();
      } else {
        $('.album').hide();
        initializeAlbums();
      }
    }
    
    // Setup display
    $("<div>", {
      id : "fb-album-header"
    }).appendTo("#" + options.id);

    $("<div>", {
      id : "fb-album-content"
    }).appendTo("#" + options.id);

    $("<div>", {
      "class" : "fb-album-footer",
      style : 'clear:both',
    }).appendTo("#" + options.id);
    
    $('.album').hide();
    
    initializeAlbums();
  };
  
  $(document).ready(function(){
    if(Drupal.settings.facebookAlbum.pageID.length){
      Drupal.facebookAlbum.initialize();
    }
  });
  
})(jQuery);
